King class

Inheritance

Constructors

King(Position position, {bool isWhite = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isWhite bool
finalinherited
position Position
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() King
override
getIcon() IconData
override
getPossiblePositions({List<List<ChessPiece?>>? board}) List<Position>
override
isPossiblePosition(int x, int y, {List<List<ChessPiece?>>? board}) bool
inherited
isValidPosition(Position pos, List<List<ChessPiece?>>? board) bool
inherited
move(Position movePosition) ChessPiece
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited